/******************************************************************************
 * Watch_Command - Watch an ongoing match
 * $Id: Watch_Command.java,v 1.7 2011/06/09 18:19:18 dick Exp $
 * 
 * jIBS - A Java clone of FIBS
 * Copyright 2002 - Axel Leucht
 * Copyright 2011 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: Watch_Command.java,v $
 * Revision 1.7  2011/06/09 18:19:18  dick
 * Use Player.println() instead of the JibsWriter.
 *
 * Revision 1.6  2011/06/06 03:18:26  dick
 * JibsMessages belongs in n.s.jibs.server, not n.s.jibs.gui
 *
 * Revision 1.5  2011/06/06 02:56:47  dick
 * getPlayer() comes from JibsServer now.
 *
 * Revision 1.4  2011/06/03 04:16:25  dick
 * When you start watching someone new, you stop watching someone old.
 *
 * Revision 1.3  2011/06/02 19:31:16  dick
 * Trying to clean up coming in as a watcher.
 * Still not getting the board out all of the time.
 *
 * Revision 1.2  2011/05/31 13:02:42  dick
 * Bucko headers.
 *
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is jIBS, <https://sourceforge.net/projects/fibs/>.
 * The Initial Developer of the Original Code is Axel Leucht.
 * 
 */
package net.sourceforge.jibs.command;

import net.sourceforge.jibs.backgammon.BackgammonBoard;
import net.sourceforge.jibs.backgammon.JibsGame;
import net.sourceforge.jibs.server.JibsMessages;
import net.sourceforge.jibs.server.JibsServer;
import net.sourceforge.jibs.server.Player;

/** Watch an ongoing match.
 *
 * @author Axel Leucht
 * @author Dick Balaska
 * @since 2004/02/11
 * @version $Revision: 1.7 $ <br> $Date: 2011/06/09 18:19:18 $
 * @see <a href="http://cvs.buckosoft.com/Projects/jIBS/jIBS/src/main/java/net/sourceforge/jibs/command/Watch_Command.java">cvs Watch_Command.java</a>
 */
public class Watch_Command implements JibsCommand {

	@Override
	public boolean execute(JibsServer jibsServer, Player player,
			String strArgs, String[] args) {
		JibsMessages jibsMessages = jibsServer.getJibsMessages();
		String msg = null;
		Object[] obj = null;

		if (args.length >= 2) {
			String Name = args[1];
			Player playingPlayer = jibsServer.getPlayer(Name);

			if (playingPlayer == null) {
				// m_noone=** There is no one called %0.
				obj = new Object[] { args[1] };
				msg = jibsMessages.convert("m_noone", obj);
				player.println(msg);

				return true;
			}
			player.stopWatching();		// turn off any existing watching
			JibsGame game = playingPlayer.getGame();
			// valid player
			playingPlayer.addWatcher(player);
			player.changeToggle("watch", Boolean.TRUE);
			player.setWatchingPlayer(playingPlayer);

			if (game == null) {
				// m_watch_no_interesting=%0 is not doing anything interesting.
				obj = new Object[] { playingPlayer.getName() };
				msg = jibsMessages.convert("m_watch_no_interesting", obj);
				player.println(msg);
				// m_you_watch_not_play=%0 is not playing
				obj = new Object[] { playingPlayer.getName() };
				msg = jibsMessages.convert("m_you_watch_not_play", obj);
				player.println(msg);
			} else {
				BackgammonBoard board = game.getBackgammonBoard();
				int d1 = board.getpDie1().getValue();
				int d2 = board.getpDie2().getValue();

				switch (board.getTurn()) {
				case 1: // O

					player.show2WatcherBoard(board, player.getName(),
							0, 0, d1, d2);
					break;

				case -1:
					playingPlayer.show2WatcherBoard(board, playingPlayer.getName(),
							d1, d2, 0, 0);
					break;
				}
			}

			return true;
		} else {
			// m_watch_who=** Watch who?
			msg = jibsMessages.convert("m_watch_who");
			player.println(msg);
		}

		return true;
	}
}
