/******************************************************************************
 * RatingCalculator - Calculate adjusted ratings after a match.
 * $Id: RatingCalculator.java,v 1.2 2011/05/31 15:25:49 dick Exp $
 * 
 * jIBS - A Java clone of FIBS
 * Copyright 2002 - Axel Leucht
 * Copyright 2011 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: RatingCalculator.java,v $
 * Revision 1.2  2011/05/31 15:25:49  dick
 * Bucko headers.
 *
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is jIBS, <https://sourceforge.net/projects/fibs/>.
 * The Initial Developer of the Original Code is Axel Leucht.
 * 
 */
package net.sourceforge.jibs.util;

/** Calculate adjusted ratings after a match. 
 * 
 * @author Axel Leucht
 * @author Dick Balaska
 * @version $Revision: 1.2 $ <br> $Date: 2011/05/31 15:25:49 $
 * @see <a href="http://cvs.buckosoft.com/Projects/jIBS/jIBS/src/main/java/net/sourceforge/jibs/util/RatingCalculator.java">cvs RatingCalculator.java</a>
 */
public class RatingCalculator {
	public static double ratingChange(boolean aWin, int length, double expA,
			double ratingA, double expB,
			double ratingB) {
		double d;
		double p;
		double p_upset;
		double k_a;
		double k_b;
		double variationA;
		double variationB;

		// experience_A += length ;
		// experience_B += length ;
		d = Math.abs(ratingA - ratingB);
		p_upset = 1 / (Math.pow(10, ((d * Math.sqrt(length)) / 2000)) + 1);
		k_a = Math.max(1, (-expA / 100) + 5);
		k_b = Math.max(1, (-expB / 100) + 5);

		if (ratingA <= ratingB) {
			if (aWin) {
				p = 1 - p_upset;
				variationA = 4 * k_a * Math.sqrt(length) * p;
				variationB = -4 * k_b * Math.sqrt(length) * p;
			} else {
				p = p_upset;
				variationA = -4 * k_a * Math.sqrt(length) * p;
				variationB = 4 * k_b * Math.sqrt(length) * p;
			}
		} else {
			if (aWin) {
				p = p_upset;
				variationA = 4 * k_a * Math.sqrt(length) * p;
				variationB = -4 * k_b * Math.sqrt(length) * p;
			} else {
				p = 1 - p_upset;
				variationA = -4 * k_a * Math.sqrt(length) * p;
				variationB = 4 * k_b * Math.sqrt(length) * p;
			}
		}

		variationA = Math.floor((variationA * 100) + 0.5) / 100.0;
		variationB = Math.floor((variationB * 100) + 0.5) / 100.0;

		if (aWin) {
			return (variationA);
		} else {
			return (variationB);
		}
	}
}
